# GetPaymentMethodSnapshotResponsePaypalType

Specifies the PayPal gateway: PayFlow Pro (Express Checkout) or Adaptive Payments.

## Enum

* `EXPRESSCHECKOUT` (value: `'ExpressCheckout'`)

* `ADAPTIVEPAYMENTS` (value: `'AdaptivePayments'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


